---
title: MongoDB Field Reference
permalink: /mongodb-field-reference/
---

## ObjectIdField

```python
class ObjectIdField(Field):
    def __init__(self, *args, **kwargs):
```

### Arguments

Same as the `Field` Base class

## ListField

> Note: To be depreciated soon and replaced with a `JSONField`

```python
class ListField(Field):
    def __init__(self, *args, **kwargs):
```

### Arguments

Same as the `Field` Base class



